@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free softwa re; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -46,7 +46,6 @@ use EBox::FileSystem;
 
 use Perl6::Junction qw(any);
 use File::Slurp;
-use Error qw(:try);
 
 use constant MAX_IFACE_NUMBER => 999999;  # this is the last number which prints
 # correctly in ifconfig
@@ -122,7 +121,7 @@ sub _enforceServiceState
 
     $self->_cleanupDeletedDaemons();
 
-    $self->_initializeInterfaces();
+    $self->initializeInterfaces();
 
     $self->_writeConfFiles();
     $self->_prepareLogFiles();
@@ -130,7 +129,10 @@ sub _enforceServiceState
     $self->_doDaemon();
 }
 
-sub _initializeInterfaces
+# Method: initializeInterfaces
+#
+#   Set interface number if has not been set
+sub initializeInterfaces
 {
     my ($self) = @_;
 
@@ -171,6 +173,11 @@ sub usedFiles
                              'To configure ripd to exchange routes with client '
                                .'to client connections'
               )
+            },
+            {
+              'file' => '/etc/default/openvpn',
+              'module' => 'openvpn',
+              'reason' => __('To remove system-wide VPN servers autostart')
             }
     ];
 }
@@ -242,6 +249,8 @@ sub _writeConfFiles
     my ($self) = @_;
 
     $self->_writeRIPDaemonConf(); # XXX RIP stuff
+    $self->writeConfFile('/etc/default/openvpn',
+        '/openvpn/default-openvpn.mas');
 
     my $confDir = $self->confDir();
 
@@ -259,14 +268,9 @@ sub _prepareLogFiles
     my $logDir = $self->logDir();
     foreach my $name (@{$self->daemonsNames()}) {
         for my $file ("$logDir/$name.log", "$logDir/status-$name.log") {
-            try {
-                EBox::Sudo::root("test -e $file");
-            }
-            otherwise {
-                EBox::Sudo::root("touch $file");
-            };
-            EBox::Sudo::root("chown root:ebox $file");
-            EBox::Sudo::root("chmod 0640 $file");
+            EBox::Sudo::root("touch '$file'",
+                             "chown root:ebox '$file'",
+                             "chmod 0640 '$file'");
         }
     }
 
@@ -828,7 +832,7 @@ sub firewallHelper
 
     # Initialize interfaces before setting fw rules
     if ($enabled and EBox::Global->getInstance()->modIsChanged('openvpn')) {
-        $self->_initializeInterfaces();
+        $self->initializeInterfaces();
     }
 
     my @ifaces = map {$_->iface() } $self->activeDaemons();
@@ -1237,6 +1241,13 @@ sub changeIfaceExternalProperty # (iface, external)
     return $self->_invokeOnDaemons('changeIfaceExternalProperty', @params);
 }
 
+sub staticIfaceAddressChanged
+{
+    my ($self, @params) = @_;
+    return $self->_anyDaemonReturnsTrue('staticIfaceAddressChanged', @params);
+}
+
+
 # common listeners helpers..
 
 sub _invokeOnServers
@@ -1393,6 +1404,7 @@ sub _setClientConf
     # unroll servers parameter
     my $server     = $params{servers}->[0]->[0];
     my $serverPort = $params{servers}->[0]->[1];
+    EBox::OpenVPN::Client->checkServer($server);
 
     my $serverPortAndProtocol = "$serverPort/" . $params{proto};
 
@@ -1423,7 +1435,7 @@ sub _setClientConf
     # remove leftover upload temporary files bz they aren't needed anymore
     foreach my $f (qw(caCertificate certificate certificateKey)) {
         my $path =  EBox::Config::tmp() . $f . '_path';
-        EBox::Sudo::root("rm -rf $path");
+        EBox::Sudo::root("rm -rf '$path'");
     }
 }
 
@@ -1557,8 +1569,9 @@ sub widgets
 
     my $widgets = {
         'openvpndaemons' => {
-            'title' => __("OpenVPN daemons"),
+            'title' => __('OpenVPN daemons'),
             'widget' => \&openVPNDaemonsWidget,
+            'order' => 13,
             'default' => 1
         }
     };
@@ -1567,7 +1580,7 @@ sub widgets
             my $widget = {
                 'title' => $ovpn->name(),
                 'widget' => \&openVPNWidget,
-                'parameter' => $ovpn->name()
+                'parameter' => $ovpn->name(),
                };
             $widgets->{'vpn' . $ovpn->name()} = $widget;
         }
@@ -1643,7 +1656,7 @@ sub tableInfo
                  };
 
     return [{
-            name => __('OpenVPN'),
+            name => $self->printableName(),
             index => 'openvpn',
             titles => $titles,
             'order' => \@order,
