@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::Client::ValidateCertificate;
 #
 use strict;
@@ -75,7 +90,7 @@ sub _verifyCert
 {
   my ($certPath) = @_;
 
-  my $cmd =  OPENSSL_PATH . ' x509 -noout -in ' . $certPath;
+  my $cmd =  OPENSSL_PATH . " x509 -noout -in '$certPath'";
   try {
     EBox::Sudo::root($cmd);
   }
@@ -90,7 +105,7 @@ sub _verifyCert
 sub _verifyPrivKey {
   my ($privKeyPath) = @_;
 
-  my $cmd = OPENSSL_PATH . ' rsa -noout -in ' . $privKeyPath;
+  my $cmd = OPENSSL_PATH . " rsa -noout -in '$privKeyPath'";
   try {
     EBox::Sudo::root($cmd);
   }
@@ -104,7 +119,7 @@ sub _verifyPrivKey {
 sub  _verifyCertWithCa
 {
   my($certPath, $caPath) = @_;
-  my $verifyParams = " -CAfile $caPath $certPath";
+  my $verifyParams = " -CAfile '$caPath' '$certPath'";
 
   my $verifyOk = _opensslVerify($verifyParams);
   unless ($verifyOk) {
@@ -124,16 +139,16 @@ sub _verifyCertWithPrivKey
 
   # XXX check ofr race condition!!
 
-  my $certCmd = OPENSSL_PATH . " x509 -pubkey -noout -in $certPath";
+  my $certCmd = OPENSSL_PATH . " x509 -pubkey -noout -in '$certPath'";
   my $certOutput = EBox::Sudo::root( $certCmd );
   write_file($fhPubCert, $certOutput);
 
-  my $keyCmd = OPENSSL_PATH . " rsa -pubout -in $privKeyPath";
+  my $keyCmd = OPENSSL_PATH . " rsa -pubout -in '$privKeyPath'";
   my $keyOutput = EBox::Sudo::root( $keyCmd );
   write_file($fhPubKey, $keyOutput);
 
   try {
-    my $diffCmd = DIFF_PATH . " --brief $pubCert $pubKey";
+    my $diffCmd = DIFF_PATH . " --brief '$pubCert' '$pubKey'";
     EBox::Sudo::root($diffCmd);
   }
   otherwise {
