@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::Daemon;
 
 # package: Parent class for the distinct types of OpenVPN daemons
@@ -121,13 +136,14 @@ sub upstartNameForDaemon
 sub _upstartFile
 {
     my ($self) = @_;
-    return  UPSTART_DIR . '/' . $self->upstartName() . '.conf';
+    return __PACKAGE__->_upstartFileForDaemon($self->name(), $self->type());
 }
 
 sub _upstartFileForDaemon
 {
     my ($class, $name, $type) = @_;
-    return  UPSTART_DIR . '/' . $class->upstartNameForDaemon($name, $type);
+    return  UPSTART_DIR . '/' . $class->upstartNameForDaemon($name, $type) .
+        '.conf';
 }
 
 sub ifaceNumber
@@ -320,7 +336,7 @@ sub writeConfFile
 
     my $confFilePath   = $self->confFile($confDir);
     my $templatePath   = $self->confFileTemplate();
-    my $templateParams = $self->confFileParams();
+    my $templateParams = $self->confFileParams(confDir => $confDir);
 
     push @{$templateParams},
       (
@@ -484,13 +500,10 @@ sub stopDeletedDaemon
     my $upstartFile = $class->_upstartFileForDaemon($name, $type);
     if (not -f $upstartFile) {
         return;
-
     }
 
     my $upstartService = $class->upstartNameForDaemon($name, $type);
     EBox::Service::manage($upstartService, 'stop');
-
-    $class->removeUpstartFileForDaemon($name, $type);
 }
 
 sub deletedDaemonCleanup
@@ -500,10 +513,10 @@ sub deletedDaemonCleanup
 
     try {
         $class->stopDeletedDaemon($name, $type);
+        $class->removeUpstartFileForDaemon($name, $type);
 
-        foreach my $file  ( $class->daemonFiles($name) ) {
-            EBox::Sudo::root(" rm -rf $file");
-
+        foreach my $file( $class->daemonFiles($name) ) {
+            EBox::Sudo::root("rm -rf '$file'");
         }
     }
     otherwise {
@@ -525,7 +538,7 @@ sub _rootCommandForStartDaemon
     my $confFilePath =   $self->confFile($confDir);
     my $pidFile = $self->_pidFile();
 
-    return "$bin  --syslog $name  --config $confFilePath";
+    return "$bin --syslog '$name' --config '$confFilePath'";
 }
 
 # Method: limitRespawn
@@ -601,7 +614,7 @@ sub writeUpstartFile
     };
 
     EBox::Module::Base::writeConfFileNoCheck(
-        $path,'/openvpn/upstart.mas',
+        $path, '/openvpn/upstart.mas',
         [ cmd => $cmd, limited => $limited],
         $fileAttrs
        );
@@ -613,7 +626,7 @@ sub removeUpstartFile
     my ($self) = @_;
 
     my $path = $self->_upstartFile();
-    EBox::Sudo::root("rm -f $path");
+    EBox::Sudo::root("rm -f '$path'");
 }
 
 sub removeUpstartFileForDaemon
@@ -625,7 +638,7 @@ sub removeUpstartFileForDaemon
       or throw EBox::Exceptions::MissingArgument('name');
 
     my $path = $class->_upstartFileForDaemon($name, $type);
-    EBox::Sudo::root("rm -f $path");
+    EBox::Sudo::root("rm -f '$path'");
 }
 
 #
