@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::FirewallHelper;
 use base 'EBox::FirewallHelper';
 
@@ -75,7 +90,8 @@ sub _inputRules
 
     # allow rip traffic in openvpn virtual ifaces
     foreach my $iface (@{ $self->ifaces() }) {
-        push @rules, "-i $iface -p udp --destination-port 520 -j ACCEPT";
+        my $input = $self->_inputIface($iface);
+        push @rules, "$input -p udp --destination-port 520 -j ACCEPT";
     }
 
     my @ports = grep {$_->{external} == $external} @{ $self->ports };
@@ -85,7 +101,7 @@ sub _inputRules
         my $proto  = $port_r->{proto};
         my $listen = $port_r->{listen};
 
-        my $inputIface = defined $listen ? "-i $listen" : "";
+        my $inputIface = defined $listen ? $self->_inputIface($listen) : "";
 
         my $rule =
           "--protocol $proto --destination-port $port $inputIface -j ACCEPT";
@@ -104,7 +120,8 @@ sub output
 
         # allow rip traffic in openvpn virtual ifaces
         foreach my $iface (@{ $self->ifaces() }) {
-            push @rules, "-o $iface -p udp --destination-port 520 -j ACCEPT";
+            my $output = $self->_outputIface($iface);
+            push @rules, "$output -p udp --destination-port 520 -j ACCEPT";
         }
 
         foreach my $server_r (@{ $self->serversToConnect() }) {
@@ -134,7 +151,8 @@ sub postrouting
     my @rules;
     foreach my $network (@networksToMasquerade) {
         foreach my $iface (@internalIfaces) {
-            push @rules, "-o $iface --source $network -j MASQUERADE";
+            my $output = $self->_outputIface($iface);
+            push @rules, "$output --source $network -j MASQUERADE";
         }
     }
 
