@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::LogHelper::Test;
 use base 'EBox::Test::Class';
 
@@ -45,19 +60,6 @@ sub fakeConfig : Test(setup)
   EBox::Module::Service::TestStub::setConfig(@config);
 }
 
-# XXX this  must be deleted if #848 is fixed
-sub fakePopulateConfFiles : Test(startup)
-{
-  Test::MockObject->fake_module('EBox::OpenVPN::LogHelper',
-				_populateLogFiles => sub {
-				  my ($self) = @_;
-				   $self->{logFiles} = $self->_logFilesFromDaemons;
-				},
-			       );
-
-}
-
-
 sub tearDownConfig: Test(teardown)
 {
   EBox::Module::Service::TestStub::setConfig();
