@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::Server::ClientBundleGenerator;
 
 # package:
@@ -146,7 +161,7 @@ sub _resolveExternalAddr
 sub _getHtmlPageCmd
 {
     my ($addrFile, $local) = @_;
-    my $cmd = "wget -O $addrFile --bind-address=$local --tries=1 --timeout=6 "
+    my $cmd = "wget -O '$addrFile' --bind-address=$local --tries=1 --timeout=6 "
       . IPResolvUrl();
     return $cmd;
 }
@@ -200,7 +215,7 @@ sub clientBundle
 
     my $bundle;
     my $tmpDir = EBox::Config::tmp() . $server->name . '-client.tmp';
-    system "rm -rf $tmpDir";
+    system "rm -rf '$tmpDir'";
     EBox::FileSystem::makePrivateDir($tmpDir);
 
     try {
@@ -210,7 +225,7 @@ sub clientBundle
         $bundle  =  $class->_createBundle($server,  $tmpDir, %params);
     }
     finally {
-        system "rm -rf $tmpDir";
+        system "rm -rf '$tmpDir'";
     };
 
     return  basename($bundle);
@@ -242,26 +257,27 @@ sub _confFile
 
 sub _createBundle
 {
-    my ($class, $server,  $tmpDir, @extraParams) = @_;
+    my ($class, $server,  $tmpDir, %extraParams) = @_;
 
-    my $bundle = $class->bundleFilename($server->name);
+    my $cn = $extraParams{clientCertificate};
+    my $bundle = $class->bundleFilename($server->name, $cn);
     my @createCmds    =
-      $class->createBundleCmds($bundle, $tmpDir, @extraParams);
+      $class->createBundleCmds($bundle, $tmpDir, %extraParams);
 
     try {
         foreach my $cmd (@createCmds) {
             EBox::Sudo::root($cmd);
         }
 
-        EBox::Sudo::root("chmod 0600 $bundle");
+        EBox::Sudo::root("chmod 0600 '$bundle'");
         my ($egid) = split '\s+', $EGID;
-        EBox::Sudo::root("chown $EUID.$egid $bundle");
+        EBox::Sudo::root("chown $EUID.$egid '$bundle'");
     }
     otherwise {
         my $ex = shift;
 
         if (defined $bundle) {
-            EBox::Sudo::root("rm -f $bundle");
+            EBox::Sudo::root("rm -f '$bundle'");
         }
 
         $ex->throw();
