@@ -1,11 +1,26 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::Server::ClientBundleGenerator::EBoxToEBox;
 use base 'EBox::OpenVPN::Server::ClientBundleGenerator';
 
-# package:
 use strict;
 use warnings;
 
 use EBox::Config;
+use EBox::Gettext;
 use File::Copy;
 use File::Slurp qw(write_file read_file);
 
@@ -21,7 +36,7 @@ sub createBundleCmds
 {
     my ($class, $bundleFile, $tmpDir) = @_;
 
-    my @filesInTmpDir = `ls $tmpDir`;
+    my @filesInTmpDir = `ls '$tmpDir'`;
     chomp @filesInTmpDir;
 
     return ("tar czf '$bundleFile' -C '$tmpDir' "
@@ -109,8 +124,17 @@ sub initParamsFromBundle
     system "rm -rf $tmpDir";
     EBox::FileSystem::makePrivateDir($tmpDir);
 
-    my $extractCmd = "tar xzf  $bundleFile -C $tmpDir";
-    EBox::Sudo::root($extractCmd);
+    try {
+        my $extractCmd = "tar xzf '$bundleFile' -C '$tmpDir'";
+        EBox::Sudo::root($extractCmd);
+    } otherwise {
+        throw EBox::Exceptions::External(
+__('This bundle is not a valid Zentyal-to-Zentyal configuration bundle. (Cannot unpack it)')
+                                         );
+    };
+
+    $class->_checkBundleContents($tmpDir);
+
 
     my @initParams;
     try {
@@ -125,7 +149,7 @@ sub initParamsFromBundle
     }
     otherwise {
         my $ex = shift @_;
-        system "rm -rf $tmpDir";
+        system "rm -rf '$tmpDir'";
         $ex->throw();
 
     };
@@ -133,11 +157,48 @@ sub initParamsFromBundle
     return @initParams;
 }
 
+
+sub _checkBundleContents
+{
+    my ($class, $tmpDir) = @_;
+
+    my $serverConfFile = $class->serverConfigurationFile($tmpDir);
+    if (not -r $serverConfFile) {
+        throw EBox::Exceptions::External(
+__('This bundle is not a valid Zentyal-to-Zentyal configuration bundle. (Missing server configuration file)')
+                                        );
+    }
+
+    my $caCertificate = $class->caFile($tmpDir);
+    if (not -r $caCertificate) {
+        throw EBox::Exceptions::External(
+__('This bundle is not a valid Zentyal-to-Zentyal configuration bundle. (Missing CA certificate file)')
+                                        );
+    }
+
+    my $certificate   = $class->certFile($tmpDir);
+    if (not -r $certificate) {
+        throw EBox::Exceptions::External(
+__('This bundle is not a valid Zentyal-to-Zentyal configuration bundle. (Missing certificate file)')
+                                        );
+    }
+
+    my $certificateKey = $class->privateKeyFile($tmpDir);
+    if (not -r $certificateKey) {
+        throw EBox::Exceptions::External(
+__('This bundle is not a valid Zentyal-to-Zentyal configuration bundle. (Missing certificate private key file)')
+                                        );
+    }
+
+
+}
+
 sub _serverConfigurationFromFile
 {
     my ($class, $tmpDir) = @_;
     my $file = $class->serverConfigurationFile($tmpDir);
 
+
     my $contents = read_file($file);
     my %conf = split ',', $contents;
 
