@@ -1,4 +1,4 @@
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -24,15 +24,20 @@ use base 'EBox::OpenVPN::Server::ClientBundleGenerator';
 
 sub bundleFilename
 {
-    my ($class, $serverName) = @_;
-    return EBox::Config::downloads() . "$serverName-client.tar.gz";
+    my ($class, $serverName, $cn) = @_;
+
+    my $filename = "$serverName-client";
+    if ($cn) {
+        $filename .= "-$cn";
+    }
+    return EBox::Config::downloads() . "$filename.tar.gz";
 }
 
 sub createBundleCmds
 {
     my ($class, $bundleFile, $tmpDir) = @_;
 
-    my @filesInTmpDir = `ls $tmpDir`;
+    my @filesInTmpDir = `ls '$tmpDir'`;
     chomp @filesInTmpDir;
 
     return ("tar czf '$bundleFile' -C '$tmpDir' "
