@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::Server::ClientBundleGenerator::Windows;
 
 # package:
@@ -14,8 +29,13 @@ use constant ZIP_PATH => '/usr/bin/zip';
 
 sub bundleFilename
 {
-    my ($class, $serverName) = @_;
-    return EBox::Config::downloads() . "$serverName-client.zip";
+    my ($class, $serverName, $cn) = @_;
+
+    my $filename = "$serverName-client";
+    if ($cn) {
+        $filename .= "-$cn";
+    }
+    return EBox::Config::downloads() . "$filename.zip";
 }
 
 sub createBundleCmds
