@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::OpenVPN::Test;
 use base 'EBox::Test::Class';
 
@@ -376,19 +391,19 @@ sub _clientCertificates
 
 sub fakeInterfaces
 {
-
-    # set fake interfaces
-    EBox::NetWrappers::TestStub::fake();
-    EBox::NetWrappers::TestStub::setFakeIfaces(
-          {
-            eth0 =>
+    my %fakeIfaces = (
+           eth0 =>
               { up => 1, address => { '192.168.0.100' => '255.255.255.0' } },
             ppp0 =>
               { up => 1, address => { '192.168.45.233' => '255.255.255.0' } },
             eth1 =>
               {up  => 1, address => { '192.168.0.233' => '255.255.255.0' }},
-          }
-    );
+
+       );
+
+    # set fake interfaces
+    EBox::NetWrappers::TestStub::fake();
+    EBox::NetWrappers::TestStub::setFakeIfaces(\%fakeIfaces);
 
     # fake network module..
     my @externalIfaces = qw(eth0 ppp0 eth1);
@@ -415,6 +430,18 @@ sub fakeInterfaces
                             ifaceExists     => $ifaceExistsSub_r,
                             ExternalIfaces  => sub { return \@externalIfaces },
                             InternalIfaces  => sub { return \@internalIfaces },
+                            ifaceAddresses  => sub {
+                                my ($self, $ifaceName) = @_;
+                                my %addresses = %{  $fakeIfaces{$ifaceName}->{address} };
+                                my @output;
+                                while (my ($addr, $netmask) = each %addresses) {
+                                    push @output, {
+                                        address => $addr,
+                                        netmask => $netmask
+                                       }
+                                }
+                                return \@output,
+                            },
                    ],
     );
 
